#' 84144 Well Selection Criteria (Codes)
#'
#' A table containing the USGS Well Selection Criteria (Codes) parameter codes.
#'
#' @format A data frame with 2 rows and 3 variables:
#' \describe{
#' \item{Parameter Code}{USGS Parameter Code}
#' \item{Fixed Value}{Fixed Value}
#' \item{Fixed Text}{Fixed Text}
#' }
#'
#'
#' @references
#' This data is from Table 26. Parameter codes with fixed values (USGS Water Quality Samples for USA: Sample Data). See \url{https://help.waterdata.usgs.gov/codes-and-parameters/}.
#'
#'
#'
#'
"pmcode_84144"
#> [1] "pmcode_84144"
